@@ -17,6 +17,7 @@
 	     (srfi srfi-13)
 	     (lily))
 
+
 (define framework-ps-module (current-module))
 
 ;;(define pdebug stderr)
@@ -275,14 +276,10 @@
 	 (embed #f))
 
 
-      (display (list filename name))
       (mkdir dir-name #o700)
 
       (set! status (ly:system
 		    (format "cd ~a && fondu -force '~a'" dir-name filename)))
-
-      (if (!= status 0)
-	  (ly:error "Fondu failed."))
       
       (set! files (dir-listing dir-name))
 
@@ -307,21 +304,22 @@
       embed))
 
     (define (font-file-as-ps-string name file-name)
+      (let*
+	  ((downcase-file-name (string-downcase file-name)))
+	
       (cond
-       ((and file-name (string-match "\\.pfa" file-name))
+       ((and file-name (string-match "\\.pfa" downcase-file-name))
 	(cached-file-contents file-name))
-       ((and file-name (string-match "\\.pfb" file-name))
+       ((and file-name (string-match "\\.pfb" downcase-file-name))
 	(ly:pfb->pfa file-name))
-       ((and file-name (string-match "\\.ttf" file-name))
+       ((and file-name (string-match "\\.ttf" downcase-file-name))
 	(ly:ttf->pfa file-name))
-       ((and file-name (string-match "\\.otf" file-name))
+       ((and file-name (string-match "\\.otf" downcase-file-name))
 	(ps-embed-cff (ly:otf->cff file-name) name 0))
-       ((and file-name (string-match "\\.ttf" file-name))
-	(ly:ttf->pfa file-name))
        (else
 	(ly:warning (_ "don't know how to embed ~S=~S") name file-name)
 	"")
-       ))
+       )))
       
   (define (load-font font-name-filename)
     (let* ((font (car font-name-filename))
@@ -561,3 +559,13 @@
 
 (define-public (convert-to-ps book name)
   #t)
+
+(define-public (output-classic-framework basename book scopes fields)
+
+  (ly:error (_ "\nThe PostScript backend does not support the 'classic'
+framework. Use the EPS backend instead,
+
+  lilypond -b eps <file>
+
+or remove the lilypond-book specific settings from the input.
+")))
